@@ -185,10 +185,10 @@ class AdsAPI(object):
         path = 'act_%s/users' % account_id
         return self.make_request(path, 'GET', batch=batch)
 
-    def get_adaccount(self, account_id, fields, batch=False):
+    def get_adaccount(self, account_id, fields=None, batch=False):
         """Returns the fields of the given ad account."""
         path = 'act_%s' % account_id
-        args = {'fields': fields}
+        args = {'fields': fields} if fields else {}
         return self.make_request(path, 'GET', args, batch=batch)
 
     def get_adaccounts(self, user_id, fields, batch=False):
@@ -240,25 +240,27 @@ class AdsAPI(object):
         args = {'fields': fields}
         return self.make_request(path, 'GET', args, batch=batch)
 
-    def get_adcampaigns(self, account_id, fields, batch=False):
+    def get_adcampaigns(self, account_id, fields=None, batch=False):
         """Returns the fields of all ad sets from the given ad account."""
         return self.get_adcampaigns_of_account(account_id, fields, batch=batch)
 
-    def get_adgroup(self, adgroup_id, fields, batch=False):
+    def get_adgroup(self, adgroup_id, fields=None, batch=False):
         """Returns the fields for the given ad group."""
         path = '%s' % adgroup_id
-        args = {'fields': fields}
+        args = {'fields': fields} if fields else {}
         return self.make_request(path, 'GET', args, batch=batch)
 
-    def get_adgroups_by_adaccount(self, account_id, batch=False):
+    def get_adgroups_by_adaccount(self, account_id, fields=None, batch=False):
         """Returns the fields of all ad groups from the given ad account."""
         path = 'act_%s/adgroups' % account_id
-        return self.make_request(path, 'GET', batch=batch)
+        args = {'fields': fields} if fields else {}
+        return self.make_request(path, 'GET', args, batch=batch)
 
-    def get_adgroups_by_adcampaign(self, campaign_id, batch=False):
+    def get_adgroups_by_adcampaign(self, campaign_id, fields=None, batch=False):
         """Returns the fields of all ad groups from the given ad campaign."""
         path = '%s/adgroups' % campaign_id
-        return self.make_request(path, 'GET', batch=batch)
+        args = {'fields': fields} if fields else {}
+        return self.make_request(path, 'GET', args, batch=batch)
 
     def get_adcreative(self, creative_id, fields, batch=False):
         """Returns the fields for the given ad creative."""
@@ -730,6 +732,33 @@ class AdsAPI(object):
             args['objective'] = objective
         return self.make_request(path, 'POST', args, batch=batch)
 
+    def update_adgroup(self, adgroup_id, name=None, bid_type=None, bid_info=None,
+                       creative_id=None, targeting=None, conversion_specs=None,
+                       tracking_specs=None, view_tags=None, objective=None,
+                       batch=False):
+        """Updates condition of the given ad group."""
+        path = "%s" % adgroup_id
+        args = {}
+        if name:
+            args['name'] = name
+        if bid_type:
+            args['bid_type'] = bid_type
+        if bid_info:
+            args['bid_info'] = json.dumps(bid_info)
+        if creative_id:
+            args['creative'] = json.dumps({'creative_id': creative_id})
+        if targeting:
+            args['targeting'] = json.dumps(targeting)
+        if conversion_specs:
+            args['conversion_specs'] = json.dumps(conversion_specs)
+        if tracking_specs:
+            args['tracking_specs'] = json.dumps(tracking_specs)
+        if view_tags:
+            args['view_tags'] = json.dumps(view_tags)
+        if objective:
+            args['objective'] = objective
+        return self.make_request(path, 'POST', args, batch=batch)
+
     def create_offsite_pixel(self, account_id, name, tag, batch=False):
         """Creates an offsite pixel for the given account."""
         path = 'act_%s/offsitepixels' % account_id
